@@ -17,7 +17,8 @@
  * Author: Jonas Danielsson <jonas@threetimestwo.org>
  */
 
-import GLib from 'gi://GLib';
+import Gio from 'gi://Gio';
+import Gdk from 'gi://Gdk';
 import Shumate from 'gi://Shumate';
 
 import * as Service from './service.js';
@@ -64,3 +65,31 @@ export function createStreetSource() {
 export function createPrintSource() {
     return createRasterRenderer(Service.getService().tiles.print);
 }
+
+export function createVectorSource() {
+    const [_status, styleFile] = Gio.file_new_for_uri('resource://org/gnome/Maps/styles/osm-liberty/style.json').load_contents(null);
+    const style = Utils.getBufferText(styleFile);
+
+    const source = Shumate.VectorRenderer.new("vector-tiles", style);
+    source.set_license("© OpenMapTiles © OpenStreetMap contributors");
+    source.set_license_uri("https://www.openstreetmap.org/copyright");
+
+    const sprites = Shumate.VectorSpriteSheet.new();
+    const [_status2, spritesJsonFile] = Gio.file_new_for_uri('resource://org/gnome/Maps/styles/osm-liberty/sprites.json').load_contents(null);
+    const spritesJson = Utils.getBufferText(spritesJsonFile);
+    sprites.add_page(
+        Gdk.Texture.new_from_resource('/org/gnome/Maps/styles/osm-liberty/sprites.png'),
+        spritesJson,
+        1
+    );
+    const [_status3, sprites2xJsonFile] = Gio.file_new_for_uri('resource://org/gnome/Maps/styles/osm-liberty/sprites@2x.json').load_contents(null);
+    const sprites2xJson = Utils.getBufferText(sprites2xJsonFile);
+    sprites.add_page(
+        Gdk.Texture.new_from_resource('/org/gnome/Maps/styles/osm-liberty/sprites@2x.png'),
+        sprites2xJson,
+        2
+    );
+    source.set_sprite_sheet(sprites);
+
+    return source;
+}
