@@ -20,21 +20,21 @@
  * Author: Marcus Lundblad <ml@update.uu.se>
  */
 
-const Application = imports.application;
-const OSMAccountDialog = imports.osmAccountDialog;
-const OSMEditDialog = imports.osmEditDialog;
-const OSMConnection = imports.osmConnection;
-const Utils = imports.utils;
+import {Application} from './application.js';
+import {OSMAccountDialog} from './osmAccountDialog.js';
+import {OSMEditDialog} from './osmEditDialog.js';
+import {OSMConnection} from './osmConnection.js';
+import * as Utils from './utils.js';
 
-/* minimum zoom level at which to offer adding a location */
-var MIN_ADD_LOCATION_ZOOM_LEVEL = 16;
+export class OSMEdit {
 
-var OSMEdit = class OSMEdit {
+    // minimum zoom level at which to offer adding a location
+    static get MIN_ADD_LOCATION_ZOOM_LEVEL() { return 16; }
 
     constructor() {
-        this._osmConnection = new OSMConnection.OSMConnection();
+        this._osmConnection = new OSMConnection();
         this._osmObject = null; // currently edited object
-        this._username = Application.settings.get('osm-username');
+        this._username = Application.settings.get('osm-username-oauth2');
         this._isSignedIn = this._username !== null && this._username.length > 0;
     }
 
@@ -43,29 +43,25 @@ var OSMEdit = class OSMEdit {
     }
 
     createEditDialog(parentWindow, place) {
-        let dialog = new OSMEditDialog.OSMEditDialog({
-            transient_for: parentWindow,
-            modal: true,
-            place: place
-        });
+        let dialog = new OSMEditDialog({ transient_for: parentWindow,
+                                         modal: true,
+                                         place: place });
 
         return dialog;
     }
 
     createEditNewDialog(parentWindow, latitude, longitude) {
-        let dialog = new OSMEditDialog.OSMEditDialog({
-            transient_for: parentWindow,
-            modal: true,
-            addLocation: true,
-            latitude: latitude,
-            longitude: longitude
-        });
+        let dialog = new OSMEditDialog({ transient_for: parentWindow,
+                                         modal: true,
+                                         addLocation: true,
+                                         latitude: latitude,
+                                         longitude: longitude });
 
         return dialog;
     }
 
     createAccountDialog(parentWindow, closeOnSignIn) {
-        let dialog = new OSMAccountDialog.OSMAccountDialog({
+        let dialog = new OSMAccountDialog({
             transient_for: parentWindow,
             modal: true,
             closeOnSignIn: closeOnSignIn
@@ -142,19 +138,8 @@ var OSMEdit = class OSMEdit {
         this._osmConnection.closeChangeset(changesetId, callback);
     }
 
-    performOAuthSignIn(username, password, callback) {
-        this._osmConnection.requestOAuthToken((success) => {
-            if (success)
-                this._onOAuthTokenRequested(username, password, callback);
-            else
-                callback(false, null);
-        });
-    }
-
-    _onOAuthTokenRequested(username, password, callback) {
-        /* keep track of authorizing username */
-        this._username = username;
-        this._osmConnection.authorizeOAuthToken(username, password, callback);
+    performOAuthSignIn() {
+        this._osmConnection.authorizeOAuthToken();
     }
 
     requestOAuthAccessToken(code, callback) {
@@ -165,21 +150,27 @@ var OSMEdit = class OSMEdit {
 
     _onOAuthAccessTokenRequested(success, callback) {
         if (success) {
-            this._isSignedIn = true;
-            Application.settings.set('osm-username', this._username);
+            this._osmConnection.fetchLoggedInUser((username) => {
+                this._isSignedIn = true;
+                /* if we couldn't retrieve the logged-in username,
+                 * e.g. if the user de-selected the permission when
+                 * authorizing the OAuth token, use a dummy placeholder
+                 * username to signify that we are signed in
+                 */
+                this._username = username ?? '_unknown_';
+                Application.settings.set('osm-username-oauth2', this._username);
+                callback(true);
+            });
         } else {
-            /* clear out username if verification was unsuccessful */
-            this._username = null;
+            callback(false);
         }
-
-        callback(success);
     }
 
     signOut() {
         this._username = null;
         this._isSignedIn = false;
 
-        Application.settings.set('osm-username', '');
+        Application.settings.set('osm-username-oauth2', '');
         this._osmConnection.signOut();
     }
 
@@ -190,4 +181,4 @@ var OSMEdit = class OSMEdit {
     get username() {
         return this._username;
     }
-};
+}
