@@ -49,10 +49,24 @@ export class PlaceBar extends Gtk.Revealer {
         Application.application.connect('notify::adaptive-mode', this._updateVisibility.bind(this));
         this.connect('notify::place', this._updatePlace.bind(this));
 
-        this._mapClick = new Gtk.GestureSingle();
+        this._mapClick = new Gtk.GestureClick();
         this._mapView.add_controller(this._mapClick);
 
-        this._mapClick.connect('begin', this._onMapClickEvent.bind(this));
+        let lat, lon;
+        this._mapClick.connect('pressed', () => {
+            lat = this._mapView.map.viewport.latitude;
+            lon = this._mapView.map.viewport.longitude;
+        });
+        this._mapClick.connect('released', () => {
+            const lat2 = this._mapView.map.viewport.latitude;
+            const lon2 = this._mapView.map.viewport.longitude;
+            /* Hide the place bar if the user clicks the map, but not if they
+               pan. */
+            if (Math.abs(lat - lat2) < 0.00001 && Math.abs(lon - lon2) < 0.00001) {
+                Application.application.selected_place = null;
+                this.reveal_child = false;
+            }
+        });
     }
 
     _updatePlace() {
@@ -74,6 +88,8 @@ export class PlaceBar extends Gtk.Revealer {
         if (this.place.store) {
             let formatter = new PlaceFormatter(this.place);
             this._title.label = formatter.title;
+        } else if (this.place.isCurrentLocation) {
+            this._title.label = _('Current Location');
         } else {
             this._title.label = '';
         }
@@ -120,17 +136,11 @@ export class PlaceBar extends Gtk.Revealer {
     _onPlaceEdited() {
         _updatePlace();
     }
-
-    _onMapClickEvent(view, event) {
-       Application.application.selected_place = null;
-       this.reveal_child = false;
-    }
 }
 
 GObject.registerClass({
     Template: 'resource:///org/gnome/Maps/ui/place-bar.ui',
-    InternalChildren: [ 'actionbar',
-                        'altSendToButton',
+    InternalChildren: [ 'altSendToButton',
                         'box',
                         'title' ],
     Properties: {
